googletest: Google testing and mocking framework
================================================

Description
-----------

C++ test framework


License
-------

BSD-3-Clause license


Upstream Contact
----------------

https://github.com/google/googletest
